@@ -4,10 +4,10 @@ Dataclass Wizard - a set of wizarding tools for interacting with `dataclasses`
 
 __title__ = 'dataclass-wizard'
 __description__ = 'Marshal dataclasses to/from JSON. Use field properties ' \
-                  'with initial values. Generate a dataclass schema for JSON ' \
-                  'input.'
+                  'with initial values. Construct a dataclass schema with ' \
+                  'JSON input.'
 __url__ = 'https://github.com/rnag/dataclass-wizard'
-__version__ = '0.8.2'
+__version__ = '0.13.0'
 __author__ = 'Ritvik Nag'
 __author_email__ = 'rv.kvetch@gmail.com'
 __license__ = 'Apache 2.0'
